##################################
### TimeIdent.tcl              ###
### Version 1.0                ###
### By Wcc                     ###
### wcc@techmonkeys.org        ###
### http://www.dawgtcl.com:81/ ###
### EFnet #|DAWG|Tcl           ###
##################################

############################################################################
### Copyright  2000 - 2002 |DAWG| Scripting Group. All rights reserved. ###
############################################################################

#########################################################################
## This script identifies to one or more nicks at 12:00 AM daily. This ##
## can be useful to keep nicks from dropping on networks that have a   ##
## nickname registration system.                                       ##
#########################################################################

##############
## COMMANDS ##
###############################################################################
## DCC ## .timeident <add|del|list|wipe> [nick] [password] (Can be changed.) ##
######### Adds or removes a nick from the auto-identify list.                ##
###############################################################################

##########################################################
## Just load the script, edit the settings, and rehash. ##
##########################################################

##############################################
# Set the command for using the script here. #
##############################################

set timeident_setting(cmd) "timeident"

#################################################
# Set the flag required to use the script here. #
#################################################

set timeident_setting(flag) "m|-"

###############################################################
# Set the nick to message here (leave as default for DALnet). #
###############################################################

set timeident_setting(dest) "NickServ@services.dal.net"

################################################
# Set the path to the nick database file here. #
################################################

set timeident_setting(db) "./scripts/timeident.db"

######################################################################
# Would you like to identify to a nick automatically after all other #
# nicks have been identified to?                                     #
######################################################################

set timeident_setting(auto) 1

########################################################################
# If you set the above setting to 1, set this to the nick and password #
# you want to use. The format is <nick>:<password>.                    #
########################################################################

set timeident_setting(autoinfo) "NICK_HERE:PASSWORD_HERE"

###################################
# Enable use of bold in DCC chat? #
###################################

set timeident_setting(bold) 1

#############################################
# Prefix "TIMEIDENT:" in DCC chat messages? #
#############################################

set timeident_setting(TIMEIDENT:) 1

####################
# Code begins here #
####################

if {![string match 1.6.* $version]} { putlog "\002TIMEIDENT:\002 \002WARNING:\002 This script is intended to run on eggdrop 1.6.x or later." }
if {[info tclversion] < 8.2} { putlog "\002TIMEIDENT:\002 \002WARNING:\002 This script is intended to run on Tcl Version 8.2 or later." }

bind dcc $timeident_setting(flag) $timeident_setting(cmd) timeident_add_del_list
bind time - "00 00 * * *" timeident_go

proc timeident_dopre {} {
	global timeident_setting
	if {!$timeident_setting(TIMEIDENT:)} { return "" }
	if {!$timeident_setting(bold)} { return "TIMEIDENT: " }
	return "\002TIMEIDENT:\002 "
}
proc timeident_readarray {array file} {
	upvar $array ours
	if {[catch {open $file r} fd]} { return }
	if {[array exists ours]} { unset ours }
	foreach line [split [read $fd] \n] {
		if {[string range $line 0 2] != "%!%" || [scan [string range $line 3 end] "%\[^!!!\]!!!%s" name data] <= 0} { continue }
		if {![info exists data]} { set data "" }
		set ours($name) $data
	}
	close $fd
}
proc timeident_savearray {array file} {
	upvar $array ours
	if {[catch {open $file w} fd] || ![array exists ours]} { return }
	foreach entry [array names ours] { puts $fd "%!%$entry!!!$ours($entry)" }
	close $fd
}
proc timeident_putdcc {idx text} { putdcc $idx "[timeident_dopre]$text" }
proc timeident_save {} {
	global timeident_setting
	timeident_savearray timeident_nickdb $timeident_setting(db)
}
if {![array exists timeident_nickdb] && [file exists $timeident_setting(db)]} { timeident_readarray timeident_nickdb $timeident_setting(db) }
proc timeident_add_del_list {hand idx text} {
	global timeident_setting timeident_nickdb
	for {set i 0} {$i <= 2} {incr i} { set arg${i} [join [lindex [split $text] $i]] }
	if {$arg0 == "" || ([string match help [string tolower $arg0]] && $arg1 == "")} {
		timeident_putdcc $idx "Usage: .$timeident_setting(cmd) <command>"
		timeident_putdcc $idx "Commands:"
		timeident_putdcc $idx "Add - Adds a nick to the database."
		timeident_putdcc $idx "Del - Removes a nick from the database."
		timeident_putdcc $idx "List - Lists all nicks that are in the database (passwords are not shown)."
		timeident_putdcc $idx "Wipe - Removes all nicks from the database."
		timeident_putdcc $idx "See .$timeident_setting(cmd) help <command> for more information."
	} elseif {[string match help [string tolower $arg0]]} {
		if {[string match html [string tolower $arg1]]} {
			timeident_putdcc $idx "Usage: .$timeident_setting(cmd) Add <nick> <password>"
			timeident_putdcc $idx "This command adds a nick to the autoidentify database."
		} elseif {[string match del [string tolower $arg1]]} {
			timeident_putdcc $idx "Usage: .$timeident_setting(cmd) Del <nick>"
			timeident_putdcc $idx "This command removes a nick from the autoidentify database."
		} elseif {[string match list [string tolower $arg1]]} {
			timeident_putdcc $idx "Usage: .$timeident_setting(cmd) List"
			timeident_putdcc $idx "This command displays a list of all nicks in the autoidentify database (passwords are not shown)."
		} elseif {[string match wipe [string tolower $arg1]]} {
			timeident_putdcc $idx "Usage: .$timeident_setting(cmd) Wipe"
			timeident_putdcc $idx "This command removes all nicks from the autoidentify database."
		} {
			timeident_putdcc $idx "No help is available for that command."
		}
	} elseif {[string match add [string tolower $arg0]]} {
		if {$arg2 == ""} { timeident_putdcc $idx "Usage: .$timeident_setting(cmd) Add <nick> <password>" ; return }
		if {[info exists timeident_nickdb([string tolower $arg1])]} { timeident_putdcc $idx "$arg1 already exists in the autoidentify database." ; return }
		set timeident_nickdb([string tolower $arg1]) $arg2
		timeident_save
		timeident_putdcc $idx "$arg1 has been added to the autoidentify database."
	} elseif {[string match del [string tolower $arg0]]} {
		if {$arg1 == ""} { timeident_putdcc $idx "Usage: .$timeident_setting(cmd) Del <nick>" ; return }
		if {![info exists timeident_nickdb([string tolower $arg1])]} { timeident_putdcc $idx "$arg1 does not exist in the autoidentify database." ; return }
		unset timeident_nickdb([string tolower $arg1])
		timeident_save
		timeident_putdcc $idx "$arg1 has been removed from the autoidentify database."
	} elseif {[string match list [string tolower $arg0]]} {
		if {![info exists timeident_nickdb] || [array size timeident_nickdb] == 0} { timeident_putdcc $idx "There are no nicks in the autoidentify database." ; return }
		timeident_putdcc $idx "Nick list:"
		foreach n [lsort -ascii [array names timeident_nickdb]] { timeident_putdcc $idx $n }
		timeident_putdcc $idx "End of list."
	} elseif {[string match wipe [string tolower $arg0]]} {
		if {![info exists timeident_nickdb] || [set nicks [array size timeident_nickdb]] == 0} { timeident_putdcc $idx "There are no nicks in the autoidentify database." ; return }
		foreach n [array names timeident_nickdb] { unset timeident_nickdb($n) }
		timeident_save
		timeident_putdcc $idx "$nicks [expr {($nicks != 1)?"nicks have":"nick has"}] been removed from the autoidentify database."
	} {
		timeident_putdcc $idx "Usage: .$timeident_setting(cmd) <command>"
		timeident_putdcc $idx "See .$timeident_setting(cmd) help for a command list."
	}
}
proc timeident_go {args} {
	global timeident_nickdb timeident_setting
	if {![info exists timeident_nickdb] || [set nicks [array size timeident_nickdb]] == 0} { return }
	foreach n [array names timeident_nickdb] { puthelp "PRIVMSG $timeident_setting(dest) :IDENTIFY $n $timeident_nickdb($n)" }
	putlog "[timeident_dopre]Identified to $nicks [expr {($nicks != 1)?"nicks":"nick"}]."
	if {!$timeident_setting(auto)} { return }
	if {[scan $timeident_setting(autoinfo) {%[^:]:%s} nick pass] != 2} { putlog "[timeident_dopre]ERROR: the autoinfo setting is not set correctly." ; return }
	puthelp "PRIVMSG $timeident_setting(dest) :IDENTIFY $nick $pass"
}
putlog "\002TIMEIDENT:\002 TimeIdent.tcl Version 1.0 by Wcc is loaded."
